Event

Enum Event 

#[non_exhaustive]
pub enum Event {
Show 40 variants EndBlockQuote, EndCaption, EndDefinitionDetail, EndDefinitionList, EndDefinitionTerm, EndDocument, EndFootnote, EndHeading, EndLink, EndOrderedListItem, EndParagraph, EndPreformatted, EndTable, EndTableCell, EndTableHeader, EndTableRow, EndUnorderedListItem, FootnoteRef { id: u32, }, Image { alt: Option<String>, decorative: bool, id: Option<String>, source: ImageSource, title: Option<String>, }, LineBreak, SoftBreak, StartBlockQuote { id: Option<String>, }, StartCaption { id: Option<String>, }, StartDefinitionDetail { id: Option<String>, }, StartDefinitionList { id: Option<String>, }, StartDefinitionTerm { id: Option<String>, }, StartDocument { id: Option<String>, language: Option<String>, metadata: Option<DocumentMeta>, }, StartFootnote { id: u32, }, StartHeading { id: Option<String>, level: u8, }, StartLink { href: String, id: Option<String>, title: Option<String>, }, StartOrderedListItem { id: Option<String>, level: u32, start: Option<u64>, style_type: ListStyleType, }, StartParagraph { alignment: Option<TextAlignment>, id: Option<String>, }, StartPreformatted { id: Option<String>, syntax: Option<String>, }, StartTable { id: Option<String>, }, StartTableCell { colspan: Option<u32>, id: Option<String>, rowspan: Option<u32>, }, StartTableHeader { abbr: Option<String>, colspan: Option<u32>, id: Option<String>, rowspan: Option<u32>, scope: Option<TableHeaderScope>, }, StartTableRow { id: Option<String>, }, StartUnorderedListItem { id: Option<String>, level: u32, style_type: ListStyleType, }, Text { content: String, style: TextStyle, }, ThematicBreak { id: Option<String>, },
}
A streaming document event.

Events flow from crate::EventSource readers to crate::EventSink writers. The enum is marked #[non_exhaustive] to allow adding new event types in future versions.

Events come in three categories:

  • Start/End pairs: Container elements like headings, paragraphs, tables
  • Self-contained: Standalone elements like text, images, line breaks
  • Block vs Inline: Block events create new vertical sections; inline events flow within blocks

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


EndBlockQuote

End a block quote.



EndCaption

End a table caption.



EndDefinitionDetail

End a definition detail.



EndDefinitionList

End a definition list.



EndDefinitionTerm

End a definition term.



EndDocument

End a document.



EndFootnote

End a footnote definition.



EndHeading

End a heading.

End a hyperlink.



EndOrderedListItem

End an ordered (numbered) list item.



EndParagraph

End a paragraph.



EndPreformatted

End a preformatted block.



EndTable

End a table.



EndTableCell

End a table data cell.



EndTableHeader

End a table header cell.



EndTableRow

End a table row.



EndUnorderedListItem

End an unordered (bulleted) list item.



FootnoteRef

A reference to a footnote.

Fields

id: u32

The footnote identifier being referenced.



Image

An image reference.

Fields

alt: Option<String>

Alternative text for accessibility.

decorative: bool

Whether the image is purely decorative (no alt text needed).

id: Option<String>

Optional block identifier for the image.

source: ImageSource

Source of the image (embedded asset or external URI).

title: Option<String>

Optional tooltip text.



LineBreak

A hard line break within a paragraph.



SoftBreak

A soft line break in source markup, such as a markdown line wrap.

Soft breaks correspond to source line wraps that do not enforce a visible break. Writers choose rendering policy: space, newline, <br>, etc.



StartBlockQuote

Begin a block quote.

Fields

id: Option<String>

Optional block identifier.



StartCaption

Begin a table caption.

Fields

id: Option<String>

Optional block identifier.



StartDefinitionDetail

Begin a definition detail (description).

Fields

id: Option<String>

Optional block identifier.



StartDefinitionList

Begin a definition list.

Fields

id: Option<String>

Optional block identifier.



StartDefinitionTerm

Begin a definition term.

Fields

id: Option<String>

Optional block identifier.



StartDocument

Begin a document with optional language and metadata.

Fields

id: Option<String>

Optional block identifier.

language: Option<String>

BCP 47 language tag (e.g., “en”, “en-US”, “zh-Hans”).

metadata: Option<DocumentMeta>

Document metadata including title, authors, and description.



StartFootnote

Begin a footnote definition.

Fields

id: u32

Unique identifier for this footnote.



StartHeading

Begin a heading of the given level.

Fields

id: Option<String>

Optional block identifier for the heading.

level: u8

Heading level, 1–9 (1 is most prominent).

Begin a hyperlink.

Fields

href: String

URL or URI target of the link.

id: Option<String>

Optional block identifier.

title: Option<String>

Optional tooltip text.



StartOrderedListItem

Begin an ordered (numbered) list item.

Fields

id: Option<String>

Optional block identifier.

level: u32

Zero-indexed nesting depth (0 = top-level list).

start: Option<u64>

Starting number for the list, populated only on the first item of an ordered list (subsequent items in the same list: None).

style_type: ListStyleType

Visual style of the list marker. Writers tolerate mismatches per ListStyleType convention.



StartParagraph

Begin a paragraph with optional alignment.

Fields

alignment: Option<TextAlignment>

Text alignment for the paragraph.

id: Option<String>

Optional block identifier for the paragraph.



StartPreformatted

Begin a preformatted (code) block with optional syntax highlighting.

Fields

id: Option<String>

Optional block identifier.

syntax: Option<String>

Language identifier for syntax highlighting (e.g., “rust”, “python”).



StartTable

Begin a table.

Fields

id: Option<String>

Optional block identifier.



StartTableCell

Begin a table data cell.

Fields

colspan: Option<u32>

Number of columns this cell spans.

id: Option<String>

Optional block identifier.

rowspan: Option<u32>

Number of rows this cell spans.



StartTableHeader

Begin a table header cell.

Fields

abbr: Option<String>

Abbreviated content for accessibility.

colspan: Option<u32>

Number of columns this cell spans.

id: Option<String>

Optional block identifier.

rowspan: Option<u32>

Number of rows this cell spans.

scope: Option<TableHeaderScope>

Whether this header applies to a column or row.



StartTableRow

Begin a table row.

Fields

id: Option<String>

Optional block identifier.



StartUnorderedListItem

Begin an unordered (bulleted) list item.

Fields

id: Option<String>

Optional block identifier.

level: u32

Zero-indexed nesting depth (0 = top-level list).

style_type: ListStyleType

Visual style of the list marker. Writers tolerate mismatches per ListStyleType convention.



Text

A text run with formatting attributes.

Fields

content: String

The text content.

style: TextStyle

Text formatting attributes.



ThematicBreak

A horizontal rule / thematic break.

Fields

id: Option<String>

Optional block identifier.